@@ -32,6 +32,7 @@ using namespace google_breakpad;
 #include <string.h>
 #endif
 
+extern "C" const char *g_module_check_init (GModule *module);
 extern "C" int gtk_module_init (int *argc, char** argv[]);
 static bool    run_bug_buddy   (const gchar *appname, pid_t pid, const gchar *minidump_path);
 static void    check_if_gdb    ();
@@ -337,3 +338,12 @@ gtk_module_init (int *argc, char** argv[])
 	}
 	return 0;
 }
+
+const char *
+g_module_check_init (GModule *module)
+{
+        g_module_make_resident (module);
+
+        return NULL;
+}
+
