@@ -40,8 +40,6 @@
 #include <bonobo/bonobo-exception.h>
 #include <bonobo-activation/bonobo-activation.h>
 
-#include <dirent.h>
-
 #include <libxml/tree.h>
 #include <libxml/parser.h>
 #include <libxml/xmlmemory.h>
@@ -462,7 +460,7 @@ bugzilla_parse_response (SoupMessage *msg, GError **err)
 {
 	GValue value;
 	int bugid = 0;
-	char *url;
+	char *url = NULL;
 
 	g_return_val_if_fail ((err == NULL || *err == NULL), NULL);
 
@@ -503,7 +501,7 @@ bugzilla_create_report (BugzillaApplication *app, int type, GnomeVersionInfo *gn
 	GHashTable *report;
 	char *user_agent;
 	char *os_version;
-	gchar *crt;
+	const gchar *crt;
     	GString *rv;
 
 	g_return_val_if_fail (app != NULL, NULL);
@@ -566,7 +564,7 @@ bugzilla_create_report (BugzillaApplication *app, int type, GnomeVersionInfo *gn
 	if (minidump_file) {
 		gchar *minidumpbuf;
 		gsize length;
-                GError *error;
+		GError *error = NULL;
 		gchar *base64 = NULL;
 
 		if (g_file_get_contents (minidump_file, &minidumpbuf, &length, &error)) {
